{% extends 'ui/layout.html' %}
{% load i18n %}

{% block content %}
    <div class="columns is-desktop">
        {% block messages %}{% endblock %}
        <div class="column p-0 is-8-desktop">
            <div>
                {% block detail_content %}{% endblock %}
            </div>
        </div>
        <div class="info-panel column is-4">
            <nav class="panel">
                {% block info_panel %}
                {% endblock %}
            </nav>
        </div>
    </div>
{% endblock %}
