.columns {
    margin: 0;
}

.columns:last-child {
    margin-bottom: 0;
}

.main-columns {
    padding-top: 52px;
    height: 100vh;
}

.column {
    padding: 0;
}

.breadcrumb * a {
    color: #0a0a0a;
}

.table td, .table th {
    padding: .2rem .75rem .2rem 0;
}

td > a {
    display:block;
    width:100%;
}

a {
    color: #0a0a0a;
}

a:visited {
    color: #0a0a0a;
}

.side-panel * .panel-block:not(:last-child) {
    border-bottom: none !important;
}

.level * {
    max-width: 100%;
}

.level * p {
    word-break: break-all;
}

input:focus {
    outline: 1px solid #48c78e !important;
    border: 1px solid #48c78e !important;
}

select:focus {
    outline: 1px solid #48c78e !important;
    border: 1px solid #48c78e !important;
}

.select:not(.is-multiple):not(.is-loading)::after {
    border-color: #48c78e;
}

.button:focus {
    outline: 1px solid #48c78e !important;
    border: 1px solid #48c78e !important;
}

.query-params {
    padding-left: 12px;
    margin-top: 4px;
}

.query-param {
    outline: none;
    padding-bottom: 4px;
}

.query-param > p:hover, .query-param:focus > p {
    background: lightgray;
    cursor: pointer;
    outline: none;
    border-radius: 4px;
}

.query-tag-group {
    display: flex;
    flex-direction: column;
    /*border: black 1px solid;*/
    margin-bottom: 4px;
    padding-bottom: 8px;
    border-radius: 4px;
    background-color: lightgray;
    cursor: pointer;
}

.query-tag-group > .query-tag {
    background-color: transparent;
    margin: 0;
    padding: 8px 8px 0 8px;
}

.query-tag {
    display: flex;
    flex-direction: row;
    justify-content: space-between;
    padding: 8px;
    margin-bottom: 8px;
    background-color: lightgray;
    border-radius: 4px;
    cursor: pointer;
}

.query-tag-text {
    word-break: break-word;
}

.selected-query-tag {
    background-color: #48c78e; !important;
}

.arrow:before {
    content: '\21B3';
}

.arrowless {
    text-indent: 13px;
}

.field.has-addons {
    margin-bottom: 0;
}

.field:not(:last-child) {
    margin-bottom: 0;
}

.label.has-field {
    height: 100%;
    display: flex;
    flex-direction: column;
    justify-content: end;
    font-weight: 300;
    word-break: break-all;
    padding: 12px 12px 12px 0;
}

.label.is-required {
    font-weight: 700;
}

@media screen and (max-width: 768px) {
    .label.has-field {
        padding: 12px 0 12px 0;
    }
}
